reset
set terminal postscript enhanced color
set output 'frqnoise.ps'

clp(f,f0) = 1/(1+{0,1}*f/f0)
lp(f,f0) = 1/sqrt(1+f**2/f0**2)

nan = sqrt(-1)
req_freq(f) = (f<0.1) ? nan : (f<0.4) ? 1000 : (f<1) ? 100 : (f<10) ? 3 : (f<20) ? 1 : (f<1000) ? 20/f : (f<10000) ? 2e-2 : nan
req_npro(f) = 10e3/f

db(x)=20.*log10(abs(x))
dbm(x) = 10**((x+10*log10(50.)-30)/20.) # dbm to volt
dbv(x) = 10**(x/20.)    # dbV to volt

set samples 1000

set title 'PMC locking frequency noise'

set logscale xy
set xlabel 'frequency (Hz)'
set format x "%.0s%c"
set ylabel 'frequency noise (Hz Hz^{-1/2})'
set format y "10^{%T}" # "%.0te%T"
set grid x y mx my
set mxtics 10
set mytics 10
set key right top 
set style data lines

ecali=1.89e-7
ccali=1.62e-8

plot [1:100e3] \
	req_npro(x) title 'NPRO' lt 1 lc 4, \
 'SRS119.DAT' u 1:($2/ecali) title 'error signal' lt 1 lc 1 w l,\
 'SRS121.DAT' u 1:($2/ecali) notitle lt 1 lc 1 w l,\
 'SRS123.DAT' u 1:($2/ecali) notitle lt 1 lc 1 w l,\
 'SRS125.DAT' u 1:($2/ecali) notitle lt 1 lc 1 w l,\
 'SRS127.DAT' u 1:($2/ecali) notitle lt 1 lc 1 w l,\
 'SRS129.DAT' u 1:($2/ecali) notitle lt 1 lc 1 w l,\
 '../c/SRS120.DAT' u 1:($2/ccali*lp($1,882)) title 'control signal' lt 1 lc 2 w l,\
 '../c/SRS122.DAT' u 1:($2/ccali*lp($1,882)) notitle lt 1 lc 2 w l,\
 '../c/SRS124.DAT' u 1:($2/ccali*lp($1,882)) notitle lt 1 lc 2 w l,\
 '../c/SRS126.DAT' u 1:($2/ccali*lp($1,882)) notitle lt 1 lc 2 w l,\
 '../c/SRS128.DAT' u 1:($2/ccali*lp($1,882)) notitle lt 1 lc 2 w l,\
 '../c/SRS130.DAT' u 1:($2/ccali*lp($1,882)) notitle lt 1 lc 2 w l

system('epstopdf --autorotate=All  frqnoise.ps')